*This file replicates Figures 1 - 4 in Keiser and Shapiro (2019). 

*Set file path for user

*SELECT USER
global user 1					 
global keiser "C:\Users\dkeiser\Documents\dropbox\JEP_WaterQualityRestrospective\replication_files\"
global shapiro "G:\Dropbox\JEP_WaterQualityRetrospective\replication_files\"
if $user == 1 cd $keiser
if $user == 2 cd $shapiro


*Figure 1: Gallup Polls

*Open data file 
use data_replication\gallup.dta, clear 

*Graph and label figure
la var pollutionofdri "Drinking water pollution"
la var pollutionofriv "River and lake pollution"
la var globalwarm "Climate change"

tw (connected pollutionofdri year, lcolor(navy) mcolor(navy)) 					///
	(connected pollutionofriv year, msymbol(D) lcolor(cranberry*.5) mcolor(cranberry*.5)) ///
	(connected airpollution year, lpattern(dash) msymbol(Sh)) 					///
	(connected globalwarm year, lpattern(dash) msymbol(Th) lcolor(dkorange) mcolor(dkorange)) ///
	(pcarrowi 71 2003 58.5 2002, lcolor(navy) mcolor(navy)) 					///
	(pcarrowi 64 2004 52 2003, lcolor(cranberry*.5) mcolor(cranberry*.5)) 			///
	(pcarrowi 46 1991 55 1992, lcolor(forest_green) mcolor(forest_green)) 		///
	(pcarrowi 22 1992 31 1993, lcolor(dkorange) mcolor(dkorange)), 				///
	graphr(color(white)) ytit("Percent") 	///
	xlab(1989 1994 1999 2004 2009 2014 2018) yscale(noline) 					///
	text(72 2003 "Drinking water pollution", place(e) color(navy)) 				///
	text(65 2004 "River and lake pollution", place(e) color(cranberry*.5)) 		///
	text(45 1989 "Air pollution", place(e) color(forest_green)) legend(off) 	///
	text(21 1989 "Climate change", place(e) color(dkorange))



*=========================================================================*
*Figure 2: US Surface Water Pollution, 1972 - 2014

use data_replication\waterquality.dta, clear

forv y = 1973/2014 {
	g byte year_`y' = year == `y'
	}

areg notfishable      year_* hour hour_2 hour_3 miss_hour doy_1 doy_2 doy_3, absorb(id_station) cluster(id_watershed) 


g xb    = _b[_cons]                   in 1
g ci_hi = _b[_cons] + 1.96*_se[_cons] in 1
g ci_lo = _b[_cons] - 1.96*_se[_cons] in 1
forv y = 1973/2014 {
	loc n = `y'-1971
	lincom _cons + year_`y'
	replace xb    = r(estimate) in `n'
	replace ci_hi = r(estimate) + 1.96 * r(se) in `n'
	replace ci_lo = r(estimate) - 1.96 * r(se) in `n'
	}
g x = _n + 1971 in 1/43

tw (connected xb x in 1/43) ///
	(line ci_hi x in 1/43, lpattern(dash) lcolor(maroon)) ///
	(line ci_lo x in 1/43, lpattern(dash) lcolor(maroon)), ///
	graphr(color(white)) ///
	yscale(noline) ///
	legend(off) ///
	xtit("Year") ///
	ytit("Share Not Fishable") ///
	subtit("") ///
	xlab(1972 1982 1992 2002 2014)




*=========================================================================*
*Figure 3: US Drinking Water Quality Violations, 1982
*The source data are from Allaire (2018) and restricted to years before 2014

*Open data file
use data_replication\dw_violations.dta, clear 

*Calculate proportion of all utilities with at least one violation in a year	
collapse (mean) all_violation_categories, by(year)
	tw connected all_violation_categories year, ///
		graphr(color(white)) ///
		yscale(noline) ///
		xtit("Year") ///
		ytit("Proportion of Systems Violating Standards") ///
		xlab(1982 1992 2002 2014) ///
		xline(1990 2002 2013)

*==============================================================================*
*Figure 4: Spending By Year                           

*Open data file 
use data_replication\spending.dta, clear

*Plot spending by year
tw (line surface year) ///
	(line drinkingwater year, lpattern(dash)) ///
	(line airtotal year if year >= 1973 & year <= 1990, lpattern(shortdash)), ///
	graphr(color(white)) ///
	yscale(noline) ///
	xtit("Year") ///
	ytit("Annual Spending (billions of 2017 dollars)") ///
	legend(order(1 "Surface Water Pollution" 2 "Drinking Water Pollution" 3 "Air Pollution"))

	


	







